@@ -123,7 +123,11 @@ func runGinkgo(ctx context.Context, wg *sync.WaitGroup, summaries chan []string,
 		}
 	}
 
-	args := []string{"--no-color", fmt.Sprintf("--timeout=%s", suiteTimeout), "-tags", "integration", "-v", "--progress"}
+	var args []string
+	if ginkgoArgs := os.Getenv("GINKGO_ARGS"); ginkgoArgs != "" {
+		args = strings.Split(ginkgoArgs, " ")
+	}
+	args = append(args, "--no-color", fmt.Sprintf("--timeout=%s", suiteTimeout), "-tags", "integration", "-v", "--progress")
 	if focus := os.Getenv("INTEGRATION_TEST_FOCUS"); focus != "" {
 		args = append(args, fmt.Sprintf(`--focus="%s"`, focus))
 	}
