@@ -1,4 +1,4 @@
-package builder
+package builder_test
 
 import (
 	"context"
@@ -6,11 +6,14 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
+	ec2types "github.com/aws/aws-sdk-go-v2/service/ec2/types"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/nodebootstrap"
 	"github.com/weaveworks/eksctl/pkg/testutils/mockprovider"
 	vpcfakes "github.com/weaveworks/eksctl/pkg/vpc/fakes"
 
+	"github.com/weaveworks/eksctl/pkg/cfn/builder"
+
 	"github.com/weaveworks/goformation/v4"
 	gfneks "github.com/weaveworks/goformation/v4/cloudformation/eks"
 )
@@ -31,7 +34,17 @@ var _ = DescribeTable("Managed Nodegroup AMI type", func(e amiTypeEntry) {
 	fakeVPCImporter := new(vpcfakes.FakeImporter)
 	bootstrapper, err := nodebootstrap.NewManagedBootstrapper(clusterConfig, e.nodeGroup)
 	Expect(err).NotTo(HaveOccurred())
-	stack := NewManagedNodeGroup(p.EC2(), clusterConfig, e.nodeGroup, nil, bootstrapper, false, fakeVPCImporter)
+	mockSubnetsAndAZInstanceSupport(clusterConfig, p,
+		[]string{"us-west-2a"},
+		[]string{}, // local zones
+		[]ec2types.InstanceType{
+			ec2types.InstanceTypeM5Large,
+			ec2types.InstanceTypeP2Xlarge,
+			ec2types.InstanceTypeA12xlarge,
+			ec2types.InstanceTypeG5gXlarge,
+			ec2types.InstanceTypeG4dnXlarge,
+		})
+	stack := builder.NewManagedNodeGroup(p.EC2(), clusterConfig, e.nodeGroup, nil, bootstrapper, false, fakeVPCImporter)
 
 	Expect(stack.AddAllResources(context.Background())).To(Succeed())
 	bytes, err := stack.RenderJSON()
