@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"os"
+	"strings"
 	"time"
 
 	"github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
@@ -11,6 +12,7 @@ import (
 	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
+	"golang.org/x/exp/slices"
 
 	"github.com/weaveworks/eksctl/pkg/ctl/cmdutils"
 	"github.com/weaveworks/eksctl/pkg/printers"
@@ -23,6 +25,7 @@ func describeStacksCmd(cmd *cmdutils.Cmd) {
 	cmd.ClusterConfig = cfg
 
 	var all, events, trail bool
+	var resourceStatus []string
 	var output printers.Type
 
 	cmd.SetDescription("describe-stacks", "Describe CloudFormation stack for a given cluster", "")
@@ -34,8 +37,9 @@ func describeStacksCmd(cmd *cmdutils.Cmd) {
 		if output != "" {
 			if cmd.CobraCommand.Flags().Changed("all") ||
 				cmd.CobraCommand.Flags().Changed("events") ||
-				cmd.CobraCommand.Flags().Changed("trails") {
-				return errors.Errorf("since the output flag is specified, the flags `all`, `events` and `trail` cannot be used")
+				cmd.CobraCommand.Flags().Changed("trails") ||
+				cmd.CobraCommand.Flags().Changed("resource-status") {
+				return errors.Errorf("since the output flag is specified, the flags `all`, `events`, `trail` and `resource-status` cannot be used")
 			}
 		}
 		switch output {
@@ -48,7 +52,7 @@ func describeStacksCmd(cmd *cmdutils.Cmd) {
 				return err
 			}
 		}
-		return doDescribeStacksCmd(cmd, all, events, trail, printer)
+		return doDescribeStacksCmd(cmd, all, events, trail, resourceStatus, printer)
 	}
 
 	cmd.FlagSetGroup.InFlagSet("General", func(fs *pflag.FlagSet) {
@@ -56,6 +60,7 @@ func describeStacksCmd(cmd *cmdutils.Cmd) {
 		cmdutils.AddRegionFlag(fs, &cmd.ProviderConfig)
 		fs.BoolVar(&all, "all", false, "include deleted stacks")
 		fs.BoolVar(&events, "events", false, "include stack events")
+		fs.StringSliceVar(&resourceStatus, "resource-status", nil, "resource statuses to filter events by, e.g. `CREATE_FAILED`, `UPDATE_FAILED`")
 		fs.BoolVar(&trail, "trail", false, "lookup CloudTrail events for the cluster")
 		fs.StringVarP(&output, "output", "o", "", "specifies the output formats (valid option: json and yaml)")
 		cmdutils.AddConfigFileFlag(fs, &cmd.ClusterConfigFile)
@@ -65,7 +70,7 @@ func describeStacksCmd(cmd *cmdutils.Cmd) {
 	cmdutils.AddCommonFlagsForAWS(cmd, &cmd.ProviderConfig, false)
 }
 
-func doDescribeStacksCmd(cmd *cmdutils.Cmd, all, events, trail bool, printer printers.OutputPrinter) error {
+func doDescribeStacksCmd(cmd *cmdutils.Cmd, all, events, trail bool, resourceStatus []string, printer printers.OutputPrinter) error {
 	if err := cmdutils.NewMetadataLoader(cmd).Load(); err != nil {
 		return err
 	}
@@ -93,6 +98,10 @@ func doDescribeStacksCmd(cmd *cmdutils.Cmd, all, events, trail bool, printer pri
 		return cmdutils.ErrMustBeSet(cmdutils.ClusterNameFlag(cmd))
 	}
 
+	if len(resourceStatus) > 0 && !events {
+		return fmt.Errorf("--resource-status flag cannot be specified without setting --events=true")
+	}
+
 	stackManager := ctl.NewStackManager(cfg)
 	stacks, err := stackManager.ListStacks(ctx)
 	if err != nil {
@@ -117,6 +126,21 @@ func doDescribeStacksCmd(cmd *cmdutils.Cmd, all, events, trail bool, printer pri
 			if err != nil {
 				logger.Critical(err.Error())
 			}
+
+			if len(resourceStatus) > 0 {
+				for i, rs := range resourceStatus {
+					resourceStatus[i] = strings.ToLower(rs)
+				}
+
+				filteredEvents := []types.StackEvent{}
+				for _, e := range events {
+					if slices.Contains(resourceStatus, strings.ToLower(string(e.ResourceStatus))) {
+						filteredEvents = append(filteredEvents, e)
+					}
+				}
+				events = filteredEvents
+			}
+
 			for i, e := range events {
 				logger.Info("CloudFormation.events/%s[%d] = %s", *s.StackName, i, StackEventToString(&e))
 			}
